@@ -5,7 +5,6 @@ DEFAULT_BASE_URL = "https://i.sjtu.edu.cn"
 
 HOME_URL = "/xtgl/index_initMenu.html"
 SCHEDULE_URL = "/kbcx/xskbcx_cxXsKb.html?gnmkdm=N2151"
-ELECT_URL = "/xsxk/zzxkyzb_cxZzxkYzbIndex.html?gnmkdm=N253512&layout=default&su="
 LOGIN_URL = "/jaccountlogin"
 LOGOUT_URL = "/logout"
 SCORE_URL = "/cjcx/cjcx_cxDgXscj.html?doType=query&gnmkdm=N305005"
@@ -17,7 +16,15 @@ COURSELIB_URL = "/design/funcData_cxFuncDataList.html?func_widget_guid=DA1B5BB30
 GPA_PARAMS_URL = "/cjgl/common_cxGnzdxxList.html?gnmkdm=N309130"
 GPA_CALC_URL = "/cjpmtj/gpapmtj_tjGpapmtj.html?gnmkdm=N309131&su="
 GPA_QUERY_URL = "/cjpmtj/gpapmtj_cxGpaxjfcxIndex.html?doType=query&gnmkdm=N309131&su="
+SELECTION_ALL_SECTORS_PARAM_URL = "/xsxk/zzxkyzb_cxZzxkYzbIndex.html?gnmkdm=N253512&layout=default&su="
+SELECTION_SECTOR_PARAM_URL = "/xsxk/zzxkyzb_cxZzxkYzbDisplay.html?gnmkdm=N253512&su="
+SELECTION_QUERY_COURSES = "/xsxk/zzxkyzb_cxZzxkYzbPartDisplay.html?gnmkdm=N253512&su="
+SELECTION_QUERY_CLASSES = "/xsxk/zzxkyzb_cxJxbWithKchZzxkYzb.html?gnmkdm=N253512&su="
+SELECTION_REGISTER = "/xsxk/zzxkyzb_xkBcZyZzxkYzb.html?gnmkdm=N253512&su="
+SELECTION_IS_REGISTERED = "/xsxk/zzxkyzb_xkJcInXksjZzxkYzb.html?gnmkdm=N253512&su="
+SELECTION_DEREGISTER = "/xsxk/zzxkyzb_tuikBcZzxkYzb.html?gnmkdm=N253512&su="
 
 HEADERS = {"User-Agent": "Mozilla/5.0 (X11; Linux x86_64; rv:71.0) Gecko/20100101 Firefox/71.0",
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8"}
 TERMS = [3, 12, 16]
+CHINESE_WEEK = {"日": 0, "一": 1, "二": 2, "三": 3, "四": 4, "五": 5, "六": 6}
