@@ -1,6 +1,7 @@
-from .base import QueryResult, Result, Results
+from .base import LazyResult, PARTIAL, QueryResult, Result, Results
 from .course import LibCourse
 from .exam import Exam, Exams
 from .gpa import CourseRange, GPA, GPAQueryParams, LogicEnum, Ranking
 from .schedule import Schedule, ScheduleCourse
 from .score import Score, ScoreFactor, Scores
+from .selection import SelectionClass, SelectionSector, SelectionSharedInfo
